@@ -3,8 +3,7 @@
 import sys
 
 def levels_options(parser):
-    parser.add_argument('--output_file', '--output', '-o', type=str,
-        default='data.txt')
+    parser.add_argument('--kind', type=str, default='audio')
     parser.add_argument('--track', type=int, default=0,
         help='what audio/video track to get. If --kind is set to motion, track will look at video streams.')
     parser.add_argument('--ffmpeg_location', default=None,
@@ -29,7 +28,6 @@ def main(sys_args=sys.argv[1:]):
 
     from auto_editor.utils.log import Log
     from auto_editor.ffwrapper import FFmpeg
-    from auto_editor.scipy.wavfile import read
 
     parser = vanparse.ArgumentParser('levels', auto_editor.version,
         description='Get loudness of audio over time.')
@@ -39,38 +37,34 @@ def main(sys_args=sys.argv[1:]):
     log = Log(temp=temp)
 
     args = parser.parse_args(sys_args, log, 'levels')
-
     ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, False)
 
     inp = ffmpeg.file_info(args.input[0])
-
     fps = 30 if inp.fps is None else float(inp.fps)
 
-    if(args.track > len(inp.audio_streams)):
-        log.error('Audio track {} does not exist.'.format(args.track))
+    if(args.kind == 'audio'):
+        from auto_editor.analyze.audio import display_audio_levels
 
-    # Split audio tracks into: 0.wav, 1.wav, etc.
-    for t in range(len(inp.audio_streams)):
-        ffmpeg.run(['-i', inp.path, '-ac', '2', '-map', '0:a:{}'.format(t),
-            os.path.join(temp, '{}.wav'.format(t))])
+        if(args.track >= len(inp.audio_streams)):
+            log.error("Audio track '{}' does not exist.".format(args.track))
 
-    sample_rate, audio_data = read(os.path.join(temp, '{}.wav'.format(args.track)))
-    audio_sample_count = audio_data.shape[0]
+        read_track = os.path.join(temp, '{}.wav'.format(args.track))
 
-    def get_max_volume(s):
-        return max(float(np.max(s)), -float(np.min(s)))
+        ffmpeg.run(['-i', inp.path, '-ac', '2', '-map', '0:a:{}'.format(args.track),
+            read_track])
 
-    max_volume = get_max_volume(audio_data)
+        if(not os.path.isfile(read_track)):
+            log.error('Audio track file not found!')
 
-    samples_per_frame = sample_rate / fps
-    audio_frame_count = int(math.ceil(audio_sample_count / samples_per_frame))
+        display_audio_levels(read_track, fps)
 
-    with open(args.output_file, 'w') as out:
-        for i in range(audio_frame_count):
-            start = int(i * samples_per_frame)
-            end = min(int((i+1) * samples_per_frame), audio_sample_count)
-            audiochunks = audio_data[start:end]
-            out.write('{}\n'.format(get_max_volume(audiochunks) / max_volume))
+    if(args.kind == 'motion'):
+        if(args.track >= len(inp.video_streams)):
+            log.error("Video track '{}' does not exist.".format(args.track))
+
+        from auto_editor.analyze.motion import display_motion_levels
+
+        display_motion_levels(inp, width=400, dilates=2, blur=21)
 
     log.cleanup()
 
